@@ -1,10 +1,10 @@
-import simple_gpg.simple_gpg
+import simple_gpg.gpg
 import sys
 
 sys.setrecursionlimit(1100)
 
 def main():
-    simple_gpg.simple_gpg.main()
+    simple_gpg.gpg.main()
 
 if __name__ == '__main__' :
     main()
